@@ -1,13 +1,12 @@
 """Script defined to test the Plan class."""
 
-
-import unittest
 import httpretty
 
+from paystackapi.tests.base_test_case import BaseTestCase
 from paystackapi.plan import Plan
 
 
-class TestPlan(unittest.TestCase):
+class TestPlan(BaseTestCase):
     """Class to test Plans."""
 
     @httpretty.activate
@@ -15,7 +14,7 @@ class TestPlan(unittest.TestCase):
         """Method defined to test plan creation."""
         httpretty.register_uri(
             httpretty.POST,
-            "https://api.paystack.co/plan",
+            self.endpoint_url("/plan"),
             content_type='text/json',
             body='{"status": true, "contributors": true}',
             status=201,
@@ -28,10 +27,10 @@ class TestPlan(unittest.TestCase):
 
     @httpretty.activate
     def test_get(self):
-        """Function defined to test Plan get method."""
+        """Method defined to test Plan get."""
         httpretty.register_uri(
             httpretty.GET,
-            "https://api.paystack.co/plan/78",
+            self.endpoint_url("/plan/78"),
             content_type='text/json',
             body='{"status": true, "contributors": true}',
             status=201,
@@ -42,10 +41,10 @@ class TestPlan(unittest.TestCase):
 
     @httpretty.activate
     def test_list(self):
-        """Function defined to test paystackapi plan list method."""
+        """Method defined to test paystackapi plan list."""
         httpretty.register_uri(
             httpretty.GET,
-            "https://api.paystack.co/plan",
+            self.endpoint_url("/plan"),
             content_type='text/json',
             body='{"status": true, "contributors": true}',
             status=201,
@@ -56,10 +55,10 @@ class TestPlan(unittest.TestCase):
 
     @httpretty.activate
     def test_update(self):
-        """Function defined to test paystackapi plan update."""
+        """Method defined to test paystackapi plan update."""
         httpretty.register_uri(
             httpretty.PUT,
-            "https://api.paystack.co/plan/78",
+            self.endpoint_url("/plan/78"),
             content_type='text/json',
             body='{"status": true, "contributors": true}',
             status=201,
